@@ -1,6 +1,5 @@
 # -*- coding: utf-8 -*-
 """ELM Ordinance full processing logic"""
-import os
 import time
 import json
 import asyncio
@@ -14,6 +13,7 @@ import pandas as pd
 from langchain.text_splitter import RecursiveCharacterTextSplitter
 
 from elm import ApiBase
+from elm.utilities import validate_azure_api_params
 from elm.ords.download import download_county_ordinance
 from elm.ords.extraction import (
     extract_ordinance_text_with_ngram_validation,
@@ -269,7 +269,7 @@ async def _process_with_logs(
 ):
     """Process counties with logging enabled."""
     counties = _load_counties_to_process(county_fp)
-    azure_api_key, azure_version, azure_endpoint = validate_api_params(
+    azure_api_key, azure_version, azure_endpoint = validate_azure_api_params(
         azure_api_key, azure_version, azure_endpoint
     )
 
@@ -379,18 +379,6 @@ def _load_counties_to_process(county_fp):
     return load_counties_from_fp(county_fp)
 
 
-def validate_api_params(azure_api_key=None, azure_version=None,
-                        azure_endpoint=None):
-    """Validate OpenAI API parameters."""
-    azure_api_key = azure_api_key or os.environ.get("AZURE_OPENAI_API_KEY")
-    azure_version = azure_version or os.environ.get("AZURE_OPENAI_VERSION")
-    azure_endpoint = azure_endpoint or os.environ.get("AZURE_OPENAI_ENDPOINT")
-    assert azure_api_key is not None, "Must set AZURE_OPENAI_API_KEY!"
-    assert azure_version is not None, "Must set AZURE_OPENAI_VERSION!"
-    assert azure_endpoint is not None, "Must set AZURE_OPENAI_ENDPOINT!"
-    return azure_api_key, azure_version, azure_endpoint
-
-
 def _configure_thread_pool_kwargs(tpe_kwargs):
     """Set thread pool workers to 5 if user didn't specify."""
     tpe_kwargs = tpe_kwargs or {}
@@ -542,8 +530,8 @@ async def process_county(
         await _record_time_and_usage(start_time, **kwargs)
         return None
 
-    doc.metadata["location"] = county
-    doc.metadata["location_name"] = county.full_name
+    doc.attrs["location"] = county
+    doc.attrs["location_name"] = county.full_name
     await _record_usage(**kwargs)
 
     doc = await extract_ordinance_text_with_ngram_validation(
@@ -562,7 +550,7 @@ async def process_county(
             "%d ordinance value(s) found for %s. Outputs are here: '%s'",
             ord_count,
             county.full_name,
-            doc.metadata["ord_db_fp"],
+            doc.attrs["ord_db_fp"],
         )
     else:
         logger.info("No ordinances found for %s.", county.full_name)
@@ -591,21 +579,21 @@ async def _record_time_and_usage(start_time, **kwargs):
 async def _move_file_to_out_dir(doc):
     """Move PDF or HTML text file to output directory."""
     out_fp = await FileMover.call(doc)
-    doc.metadata["out_fp"] = out_fp
+    doc.attrs["out_fp"] = out_fp
     return doc
 
 
 async def _write_cleaned_text(doc):
     """Write cleaned text to `clean_dir`."""
     out_fp = await CleanedFileWriter.call(doc)
-    doc.metadata["cleaned_fp"] = out_fp
+    doc.attrs["cleaned_fp"] = out_fp
     return doc
 
 
 async def _write_ord_db(doc):
     """Write cleaned text to `county_dbs_dir`."""
     out_fp = await OrdDBFileWriter.call(doc)
-    doc.metadata["ord_db_fp"] = out_fp
+    doc.attrs["ord_db_fp"] = out_fp
     return doc
 
 
@@ -640,10 +628,10 @@ def _num_ords_in_doc(doc):
     if doc is None:
         return 0
 
-    if "ordinance_values" not in doc.metadata:
+    if "ordinance_values" not in doc.attrs:
         return 0
 
-    ord_vals = doc.metadata["ordinance_values"]
+    ord_vals = doc.attrs["ordinance_values"]
     if ord_vals.empty:
         return 0
 
@@ -678,16 +666,16 @@ def _docs_to_db(docs):
 
 def _db_results(doc):
     """Extract results from doc metadata to DataFrame."""
-    results = doc.metadata.get("ordinance_values")
+    results = doc.attrs.get("ordinance_values")
     if results is None:
         return None
 
-    results["source"] = doc.metadata.get("source")
-    year = doc.metadata.get("date", (None, None, None))[0]
+    results["source"] = doc.attrs.get("source")
+    year = doc.attrs.get("date", (None, None, None))[0]
     results["ord_year"] = year if year is not None and year > 0 else None
     results["last_updated"] = datetime.now().strftime("%m/%d/%Y")
 
-    location = doc.metadata["location"]
+    location = doc.attrs["location"]
     results["FIPS"] = location.fips
     results["county"] = location.name
     results["state"] = location.state
